<?php

namespace Drupal\static_export\Exporter\Output\Config\Definition;

use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\static_export\Exporter\Output\Config\Definition\Path\ExporterOutputConfigDefinitionPathInterface;

/**
 * Definition of the output of a exporter.
 *
 * This class is meant to be instantiated using
 * ExporterOutputConfigFactoryInterface::create() method and shouldn't be
 * manually instantiated.
 */
class ExporterOutputConfigDefinition implements ExporterOutputConfigDefinitionInterface {

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * The path object to use in a configuration definition.
   *
   * @var \Drupal\static_export\Exporter\Output\Config\Definition\Path\ExporterOutputConfigDefinitionPathInterface
   */
  protected $path;

  /**
   * Export format.
   *
   * @var string
   */
  protected $format;

  /**
   * Export language.
   *
   * @var \Drupal\Core\Language\LanguageInterface
   */
  protected $language;

  /**
   * Exporter output config definition constructor.
   *
   * @param \Drupal\Core\Language\LanguageManagerInterface $languageManager
   *   The language manager.
   * @param \Drupal\static_export\Exporter\Output\Config\Definition\Path\ExporterOutputConfigDefinitionPathInterface $path
   *   The path object to use in a configuration definition.
   */
  public function __construct(LanguageManagerInterface $languageManager, ExporterOutputConfigDefinitionPathInterface $path) {
    $this->languageManager = $languageManager;
    $this->path = $path;
  }

  /**
   * {@inheritdoc}
   */
  public function getPath(): ExporterOutputConfigDefinitionPathInterface {
    return $this->path;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormat(): string {
    return $this->format ?: $this->getPath()->getExtension();
  }

  /**
   * {@inheritdoc}
   */
  public function setFormat(string $format): ExporterOutputConfigDefinitionInterface {
    $this->format = $format;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getLanguage(): LanguageInterface {
    return $this->language ?: $this->languageManager->getDefaultLanguage();
  }

  /**
   * {@inheritdoc}
   */
  public function setLanguage(LanguageInterface $language): ExporterOutputConfigDefinitionInterface {
    $this->language = $language;
    return $this;
  }

}
