<?php

namespace Drupal\static_export\Exporter\Type\Config\Output\Uri\Resolver;

use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\static_export\Exporter\Output\Uri\Resolver\ExporterUriResolverBase;
use Drupal\static_export\Exporter\Output\Uri\UriInterface;
use Drupal\static_export\Exporter\Type\Config\ConfigExporterPluginManagerInterface;
use Drupal\static_suite\Entity\EntityUtilsInterface;

/**
 * URI resolver service for exported configuration objects.
 */
class ConfigExporterUriResolver extends ExporterUriResolverBase implements ConfigExporterUriResolverInterface {

  /**
   * Language Manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * Config exporter instance.
   *
   * @var \Drupal\static_export\Exporter\Type\Config\ConfigExporterPluginInterface
   */
  protected $configExporter;

  /**
   * Config exporter Manager.
   *
   * @var \Drupal\static_export\Exporter\Type\Config\ConfigExporterPluginManagerInterface
   */
  protected $configExporterManager;

  /**
   * The entity utils.
   *
   * @var \Drupal\static_suite\Entity\EntityUtilsInterface
   */
  protected $entityUtils;

  /**
   * Config name to work with.
   *
   * @var string
   */
  protected $configName;

  /**
   * Uri Resolver service constructor.
   *
   * @param \Drupal\Core\Language\LanguageManagerInterface $languageManager
   *   Language Manager.
   * @param \Drupal\static_export\Exporter\Type\Config\ConfigExporterPluginManagerInterface $configExporterManager
   *   Config exporter Manager.
   * @param \Drupal\static_suite\Entity\EntityUtilsInterface $entityUtils
   *   Entity utils.
   */
  public function __construct(
    LanguageManagerInterface $languageManager,
    ConfigExporterPluginManagerInterface $configExporterManager,
    EntityUtilsInterface $entityUtils
  ) {
    $this->languageManager = $languageManager;
    $this->configExporterManager = $configExporterManager;
    $this->entityUtils = $entityUtils;
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function setConfigName(string $configName): ConfigExporterUriResolverInterface {
    $this->configName = $configName;
    $this->configExporter = $this->configExporterManager->createDefaultInstance();
    return $this;
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\static_suite\StaticSuiteUserException
   */
  public function getMainUri(): ?UriInterface {
    return $this->configExporter->setOptions(['name' => $this->configName])->getUri();
  }

  /**
   * {@inheritdoc}
   *
   * @param string $langcode
   *   Optional language id.
   *
   * @throws \Drupal\static_suite\StaticSuiteUserException
   */
  public function getVariantUris(string $langcode = NULL): array {
    $uris = [];
    $configExporter = $this->configExporter->setOptions(['name' => $this->configName, 'language' => $langcode]);
    foreach ($configExporter->getVariantKeys() as $variantKey) {
      $uris[] = $this->configExporter->setOptions(['name' => $this->configName, 'language' => $langcode, 'variant' => $variantKey])->getUri();
    }
    // Remove null values by using array_filter.
    return array_filter($uris);
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\static_suite\StaticSuiteUserException
   */
  public function getTranslationUris(): array {
    $uris = [];
    $configExporter = $this->configExporter->setOptions(['name' => $this->configName]);
    foreach ($configExporter->getTranslationLanguages() as $translationKey) {
      $uris[] = $this->configExporter->setOptions(['name' => $this->configName, 'language' => $translationKey])->getUri();
      // Variants from translations must also be added to the result.
      $translationVariants = $this->getVariantUris($translationKey);
      foreach ($translationVariants as $translationVariant) {
        $uris[] = $translationVariant;
      }
    }
    // Remove null values by using array_filter.
    return array_filter($uris);
  }

}
