<?php

namespace Drupal\static_export\File\MimeType;

use Drupal\Core\File\MimeType\MimeTypeGuesser as BaseMimeTypeGuesser;
use Drupal\Core\StreamWrapper\StreamWrapperManagerInterface;
use Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface;

/**
 * Defines a MIME type guesser for Static Export.
 */
class MimeTypeGuesser extends BaseMimeTypeGuesser {

  /**
   * @var \Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface
   */
  protected $inner;

  /**
   * Constructs a MimeTypeGuesser object.
   *
   * @param \Drupal\Core\StreamWrapper\StreamWrapperManagerInterface $stream_wrapper_manager
   *   The stream wrapper manager.
   */
  public function __construct(MimeTypeGuesserInterface $inner, StreamWrapperManagerInterface $stream_wrapper_manager) {
    $this->inner = $inner;
    parent::__construct($stream_wrapper_manager);
  }

  /**
   * {@inheritdoc}
   */
  public function guess($path) {
    $mimetype = parent::guess($path);
    if (!$mimetype) {
      $mimetype = $this->inner->guess($path);
    }
    return $mimetype;
  }

}
