<?php

namespace Drupal\static_suite\Lock;

use Drupal\Core\Database\Connection;
use Drupal\Core\Lock\DatabaseLockBackend as DatabaseLockBackendBase;

/**
 * Defines the database lock backend. This is the default backend in Drupal.
 *
 * @ingroup lock
 */
class DatabaseLockBackend extends DatabaseLockBackendBase implements LockBackendInterface {

  /**
   * {@inheritdoc}
   */
  public function __construct(Connection $database) {
    parent::__construct($database);

    // Register shutdown callbacks when running on CLI to void stale semaphores.
    if (function_exists('pcntl_signal')) {
      pcntl_async_signals(TRUE);
      pcntl_signal(SIGTERM, [$this, 'releaseAll']);
      pcntl_signal(SIGINT, [$this, 'releaseAll']);
      pcntl_signal(SIGQUIT, [$this, 'releaseAll']);
      pcntl_signal(SIGHUP, [$this, 'releaseAll']);
      pcntl_signal(SIGUSR1, [$this, 'releaseAll']);
    }
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Exception
   */
  public function acquireOrWait(string $name, float $timeout = 30.0, int $delay = 30): bool {
    return (
      $this->acquire($name, $timeout)
      || (
        !$this->wait($name, $delay)
        && $this->acquire($name, $timeout)
      )
    );
  }

  /**
   * {@inheritdoc}
   */
  public function isAcquired(string $name): bool {
    return isset($this->locks[$name]);
  }

}
